#[repr(u16)]pub enum InputFlags {
InputFlagScancodes = 1,
InputFlagMousex = 4,
InputFlagFastpathInput = 8,
InputFlagUnicode = 16,
InputFlagFastpathInput2 = 32,
InputFlagUnused1 = 64,
InputFlagUnused2 = 128,
TsInputFlagMouseHwheel = 256,
}Variants
InputFlagScancodes = 1
Raw Keyboard scancode This is the most convenient way to send keyboard event This fearture is supported by rdp-rs
InputFlagMousex = 4
This is the extended mouse event with more button code This feature is supported by rdp-rs
InputFlagFastpathInput = 8
The capability to send fastpath input This feature is NOT supported by rdp-rs
InputFlagUnicode = 16
In order to send keyboard scancode We can send directly UNICODE code of char Usefull if we want to send script This feature is supported by rdp-rs
InputFlagFastpathInput2 = 32
InputFlagUnused1 = 64
InputFlagUnused2 = 128
TsInputFlagMouseHwheel = 256
Support of the mouse wheel This feature is supported by rdp-rs